/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  TypeScript Library for the Mastodon API

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import type Account from './Account.js';
import type Application from './Application.js';
import type Card from './Card.js';
import type Emoji from './Emoji.js';
import type MediaAttachment from './MediaAttachment.js';
import type Poll from './Poll.js';
import type Tag from './Tag.js';
import type Visibility from './Visibility.js';
export interface MediaStatusPost {
    id?: string;
    in_reply_to_id?: string;
    media_ids: Array<string>;
    poll?: undefined;
    scheduled_at?: Date;
    sensitive?: boolean;
    spoiler_text?: string;
    status?: string;
    visibility?: Visibility;
}
export interface Status {
    account: Account;
    application?: Application;
    bookmarked?: boolean;
    card?: (Card | null);
    created_at: string;
    content: string;
    edited_at?: string;
    emojis: Array<Emoji>;
    favourited?: boolean;
    favourites_count: number;
    id: string;
    in_reply_to_account_id?: (string | null);
    in_reply_to_id?: (string | null);
    language?: (string | null);
    media_attachments: Array<MediaAttachment>;
    mentions: Array<StatusMention>;
    muted?: boolean;
    pinned?: boolean;
    poll?: (Poll | null);
    reblog?: (Status | null);
    reblogged?: boolean;
    reblogs_count: number;
    replies_count: number;
    sensitive: boolean;
    spoiler_text: string;
    tags: Array<Tag>;
    text?: (string | null);
    uri: string;
    url?: (string | null);
    visibility: Visibility;
}
export interface StatusContext {
    ancestors: Array<Status>;
    descendants: Array<Status>;
}
export interface StatusMention {
    acct: string;
    id: string;
    username: string;
    url: string;
}
export type StatusPost = (MediaStatusPost | TextStatusPost);
export interface StatusSchedule {
    id: string;
    media_attachments: Array<MediaAttachment>;
    params: Partial<Status>;
    scheduled_at: string;
}
export interface TextStatusPost {
    id?: string;
    in_reply_to_id?: string;
    media_ids?: undefined;
    poll?: TextStatusPostPoll;
    scheduled_at?: Date;
    sensitive?: boolean;
    spoiler_text?: string;
    status: string;
    visibility?: Visibility;
}
export interface TextStatusPostPoll {
    expires_in: number;
    hide_totals?: boolean;
    multiple?: boolean;
    options: Array<string>;
}
export declare function isStatus(json: Partial<Status>): json is Status;
export declare function isStatusContext(json: Partial<StatusContext>): json is StatusContext;
export declare function isStatuses(json: Partial<Array<Partial<Status>>>): json is Array<Status>;
export declare function isStatusMention(json: Partial<StatusMention>): json is StatusMention;
export declare function isStatusSchedule(json: Partial<StatusSchedule>): json is StatusSchedule;
export default Status;
